pub fn upload_bytes(
ctx: &GpuContextHandle,
bytes: &[u8],
) -> Result<GpuBufferHandle, GpuError>Expand description
Simple upload helper: allocates an upload buffer and returns it with bytes staged length.
pub fn upload_bytes(
ctx: &GpuContextHandle,
bytes: &[u8],
) -> Result<GpuBufferHandle, GpuError>Simple upload helper: allocates an upload buffer and returns it with bytes staged length.